@@ -2,7 +2,7 @@ import os.path
 
 __all__ = ('__version__', '__build__')
 
-__version__ = (0, 1)
+__version__ = (0, 1, 1)
 
 def _get_git_revision(path):
     revision_file = os.path.join(path, 'refs', 'heads', 'master')
@@ -26,6 +26,4 @@ def get_revision():
         return _get_git_revision(path)
     return None
 
-__build__ = get_revision()
-
-from feedreader import *
\ No newline at end of file
+__build__ = get_revision()
\ No newline at end of file
